@@ -3,12 +3,17 @@
 //! This module provides PyO3-based Python bindings for the sy Rust crate,
 //! exposing all major sync functionality with a Pythonic API.
 
+// False positive: clippy flags return type annotations as "useless conversions"
+#![allow(clippy::useless_conversion)]
+
 mod cli;
 mod config;
+mod dryrun;
 mod error;
+mod ls;
 mod options;
 mod path;
-mod progress;
+pub mod progress;
 mod stats;
 mod sync;
 
@@ -22,6 +27,7 @@ fn _sypy(m: &Bound<'_, PyModule>) -> PyResult<()> {
     m.add_class::<stats::PySyncError>()?;
     m.add_class::<path::PySyncPath>()?;
     m.add_class::<options::PySyncOptions>()?;
+    m.add_class::<ls::PyListEntry>()?;
 
     // Register config classes
     m.add_class::<config::PyCloudClientOptions>()?;
@@ -29,10 +35,21 @@ fn _sypy(m: &Bound<'_, PyModule>) -> PyResult<()> {
     m.add_class::<config::PyGcsConfig>()?;
     m.add_class::<config::PySshConfig>()?;
 
+    // Register dry-run classes
+    m.add_class::<dryrun::PyChangeAction>()?;
+    m.add_class::<dryrun::PyFileChange>()?;
+    m.add_class::<dryrun::PyDirectoryChange>()?;
+    m.add_class::<dryrun::PySymlinkChange>()?;
+    m.add_class::<dryrun::PyDryRunDetails>()?;
+
+    // Register progress classes
+    m.add_class::<progress::PyProgressSnapshot>()?;
+
     // Register functions
     m.add_function(wrap_pyfunction!(sync::sync, m)?)?;
     m.add_function(wrap_pyfunction!(sync::sync_with_options, m)?)?;
     m.add_function(wrap_pyfunction!(path::parse_path, m)?)?;
+    m.add_function(wrap_pyfunction!(ls::ls, m)?)?;
 
     // Register CLI functions
     m.add_function(wrap_pyfunction!(cli::main, m)?)?;
